@@ -1,6 +1,6 @@
 #!/bin/bash
 #  This script is part of Numdiff
-#  Copyright (C)  2005-2012    Ivano Primi  <ivprimi@libero.it>    
+#  Copyright (C)  2005-2013    Ivano Primi  <ivprimi@libero.it>    
 #
 #   Copying and distribution of this file, with or without modification,
 #   are permitted in any medium without royalty provided the copyright
@@ -8,15 +8,15 @@
 
 LESS="less"
 DIFF="diff"
-#DIFF=/home/ivano/myprojs/numdiff/tests/Numdiff
 NUMDIFF="numdiff"
-#NUMDIFF="/home/ivano/myprojs/numdiff-5.2.0/numdiff"
+NDSELECT="ndselect"
 
 echo "Viewer: $LESS"
 echo "Tester program: $DIFF"
 echo "Numdiff: $NUMDIFF"
+echo "Ndselect: $NDSELECT"
 
-TESTS="test1 test2 test4 test7 test8 test9 test10 test11 test12 test13 test14 test15 test16 test17 test18 test19 test21 test22 test24 test25 test26 test27 test28 test29 test30"
+TESTS="test1 test2 test4 test7 test8 test9 test10 test11 test12 test13 test14 test15 test16 test17 test18 test19 test21 test22 test24 test25 test26 test27 test28 test29 test30 test31 test32"
 
 for TEST in $TESTS
 do
@@ -27,6 +27,6 @@ do
   fi
   echo -e "\nCurrent working directory: $PWD"
   RUNTEST="./run${TEST}b.sh"
-  $RUNTEST $LESS $DIFF $NUMDIFF
+  $RUNTEST $LESS $DIFF $NUMDIFF $NDSELECT
 done
 
